@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -20,6 +20,7 @@ import forge
 import numpy as np
 
 from qctrlcommons.exceptions import QctrlException
+from qctrlcommons.node.arithmetic_unary import check_operand_type
 from qctrlcommons.node.base import Node
 from qctrlcommons.node.documentation import Category
 from qctrlcommons.node.node_data import (
@@ -45,7 +46,14 @@ from qctrlcommons.preconditions import (
 
 
 def _create_flexible_binary_node_data(
-    _operation, op_name, x, y, name, validate_value_shape=validate_broadcasted_shape
+    _operation,
+    op_name,
+    x,
+    y,
+    name,
+    validate_value_shape=validate_broadcasted_shape,
+    can_x_be_number=True,
+    can_y_be_number=True,
 ):
     """
     Common implementation of `create_node_data` for nodes acting on Tensors, Pwcs, and Stfs
@@ -70,12 +78,18 @@ def _create_flexible_binary_node_data(
         shouldn't assume that the shapes are compatible, and raise an
         exception if they aren't. The names provided should be used to
         generate the error message.
+    can_x_be_number : bool, optional
+        Whether x can be a number or not. Defaults to True.
+    can_y_be_number : bool, optional
+        Whether y can be a number or not. Defaults to True.
 
     Returns
     -------
     Tensor or Pwc or Stf
         The operation acting on the object.
     """
+    check_operand_type(x, "x", can_be_number=can_x_be_number)
+    check_operand_type(y, "y", can_be_number=can_y_be_number)
     # operation(Pwc, Stf) or operation(Stf, Pwc)
     check_argument(
         not (isinstance(x, Pwc) and isinstance(y, Stf))
@@ -596,7 +610,12 @@ class Matmul(Node):
             return trailing_shape + (x_shape[-2], y_shape[-1])
 
         return _create_flexible_binary_node_data(
-            _operation, "matmul", validate_value_shape=_validate_value_shape, **kwargs
+            _operation,
+            "matmul",
+            validate_value_shape=_validate_value_shape,
+            can_x_be_number=False,
+            can_y_be_number=False,
+            **kwargs,
         )
 
 
@@ -675,5 +694,10 @@ class Kron(Node):
             )
 
         return _create_flexible_binary_node_data(
-            _operation, "kron", validate_value_shape=_validate_value_shape, **kwargs
+            _operation,
+            "kron",
+            validate_value_shape=_validate_value_shape,
+            can_x_be_number=False,
+            can_y_be_number=False,
+            **kwargs,
         )
