@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -14,12 +14,14 @@
 # pylint: disable=too-many-lines
 """Module for unary operation nodes."""
 
+from numbers import Number
 from typing import (
     Tuple,
     Union,
 )
 
 import forge
+import numpy as np
 
 from qctrlcommons.node.base import Node
 from qctrlcommons.node.documentation import Category
@@ -40,7 +42,44 @@ from qctrlcommons.preconditions import (
 )
 
 
-def _create_flexible_unary_node_data(_operation, x, name, value_shape_changer=None):
+def check_operand_type(x, name, can_be_number):
+    """
+    Check the operand is a number, a NumPy array, a Pwc, an Stf, or a Tensor.
+
+    The check also passes if the argument can possibly be a QuTiP operator (has
+    a `full` argument).
+
+    Parameters
+    ----------
+    x : Any
+        The operand to be checked.
+    name : str
+        Name of the operand.
+    can_be_number : bool
+        Whether the operand can be number.
+    """
+    if can_be_number:
+        types = (Pwc, Stf, Tensor, np.ndarray, Number)
+        message = (
+            f"The variable {name} must be a number, a NumPy array, a Pwc, an Stf, "
+            "or a Tensor."
+        )
+    else:
+        types = (Pwc, Stf, Tensor, np.ndarray)
+        message = (
+            f"The variable {name} must be a NumPy array, a Pwc, an Stf, or a Tensor."
+        )
+    check_argument(
+        isinstance(x, types) or hasattr(x, "full"),
+        message,
+        {name: x},
+        extras={f"type({name})": type(x)},
+    )
+
+
+def _create_flexible_unary_node_data(
+    _operation, x, name, value_shape_changer=None, can_be_number=True
+):
     """
     Common implementation of `create_node_data` for nodes acting on Tensors, Pwcs, and Stfs
     implementing unary functions.
@@ -56,12 +95,15 @@ def _create_flexible_unary_node_data(_operation, x, name, value_shape_changer=No
     value_shape_changer : Callable[[tuple], tuple], optional
         Callable that transforms the original shape of the object into the shape after the operation
         is applied. Defaults to an identity operation, that is to say, to not change the shape.
+    can_be_number : bool
+        Whether the input variable can be numeric scalar. Defaults to True.
 
     Returns
     -------
     Tensor or Pwc or Stf
         The operation acting on the object.
     """
+    check_operand_type(x, "x", can_be_number)
 
     # By default don't change shapes.
     def get_value_shape(shape):
@@ -780,7 +822,10 @@ class Adjoint(Node):
             return (*batch, y, x)
 
         return _create_flexible_unary_node_data(
-            _operation, **kwargs, value_shape_changer=value_shape_changer
+            _operation,
+            **kwargs,
+            value_shape_changer=value_shape_changer,
+            can_be_number=False,
         )
 
 
@@ -831,7 +876,10 @@ class Trace(Node):
             return value_shape[:-2]
 
         return _create_flexible_unary_node_data(
-            _operation, **kwargs, value_shape_changer=value_shape_changer
+            _operation,
+            **kwargs,
+            value_shape_changer=value_shape_changer,
+            can_be_number=False,
         )
 
 
@@ -922,5 +970,8 @@ class HermitianPart(Node):
             return value_shape
 
         return _create_flexible_unary_node_data(
-            _operation, **kwargs, value_shape_changer=value_shape_changer
+            _operation,
+            **kwargs,
+            value_shape_changer=value_shape_changer,
+            can_be_number=False,
         )
