@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -776,9 +776,9 @@ class WignerTransform(Node):
     density_matrix : Tensor or np.ndarray
         The density matrix :math:`\rho` in the Fock basis.
         Must be of shape ``(..., D, D)``.
-    position : np.ndarray
+    position : list or tuple or np.ndarray
         The dimensionless position vector :math:`q`. Must be a 1D array of shape ``(L,)``.
-    momentum : np.ndarray
+    momentum : list or tuple or np.ndarray
         The dimensionless momentum vector :math:`p`. Must be a 1D array of shape ``(K,)``.
     offset : int, optional
         The lowest Fock state. Defaults to 0.
@@ -790,6 +790,17 @@ class WignerTransform(Node):
     Tensor
         The Wigner function with shape ``(..., L, K)``.
 
+    Warnings
+    --------
+    This function currently does not support calculating the gradient with respect to its inputs.
+    Therefore, it cannot be used in a graph for a `calculate_optimization` or
+    `calculate_stochastic_optimization` call, which will raise a `RuntimeError`.
+    Please use gradient-free optimization if you want to perform an optimization task with this
+    function. You can learn more about it in the
+    `How to optimize controls using gradient-free optimization
+    <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-optimize-controls-using-gradient-free-optimization>`_
+    user guide.
+
     See Also
     --------
     coherent_state : Create a coherent state (or a batch of them).
@@ -812,7 +823,7 @@ class WignerTransform(Node):
     --------
     Create a Wigner function.
 
-    >>> graph.wigner_transform(np.array([[1]]), np.array([-1, 0, 1]), np.zeros(1), name="wigner")
+    >>> graph.wigner_transform(np.array([[1]]), [-1, 0, 1], np.zeros(1), name="wigner")
     <Tensor: name="wigner", operation_name="wigner_transform", shape=(3, 1)>
     >>> result = qctrl.functions.calculate_graph(graph=graph, output_node_names=["wigner"])
     >>> result.output["wigner"]["value"]
@@ -843,8 +854,8 @@ class WignerTransform(Node):
     name = "wigner_transform"
     args = [
         forge.arg("density_matrix", type=Union[Tensor, np.ndarray]),
-        forge.arg("position", type=np.ndarray),
-        forge.arg("momentum", type=np.ndarray),
+        forge.arg("position", type=Union[list, tuple, np.ndarray]),
+        forge.arg("momentum", type=Union[list, tuple, np.ndarray]),
         forge.arg("offset", type=int, default=0),
     ]
 
@@ -855,7 +866,9 @@ class WignerTransform(Node):
     def create_node_data(cls, _operation, **kwargs):
         density_matrix = kwargs.get("density_matrix")
         position = kwargs.get("position")
+        position = np.asarray(position)
         momentum = kwargs.get("momentum")
+        momentum = np.asarray(momentum)
         offset = kwargs.get("offset")
 
         check_argument(
