@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -344,7 +344,7 @@ class InfidelityStf(Node):
 
     Parameters
     ----------
-    sample_times : np.ndarray(1D, real)
+    sample_times : list or tuple or np.ndarray(1D, real)
         The times at which the Hamiltonian and noise operators (if present) should be sampled for
         the integration. Must start with 0, be ordered, and contain at least one element.
     hamiltonian : Stf
@@ -405,7 +405,7 @@ class InfidelityStf(Node):
 
     name = "infidelity_stf"
     args = [
-        forge.arg("sample_times", type=np.ndarray),
+        forge.arg("sample_times", type=Union[list, tuple, np.ndarray]),
         forge.arg("hamiltonian", type=Stf),
         forge.arg("target", type=Target),
         forge.arg(
@@ -420,6 +420,7 @@ class InfidelityStf(Node):
     @classmethod
     def create_node_data(cls, _operation, **kwargs):
         sample_times = kwargs.get("sample_times")
+        sample_times = np.asarray(sample_times)
         hamiltonian = kwargs.get("hamiltonian")
         target = kwargs.get("target")
         noise_operators = kwargs.get("noise_operators")
