@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -14,6 +14,7 @@
 from typing import (
     List,
     Optional,
+    Union,
 )
 
 import forge
@@ -65,7 +66,7 @@ class MsPhases(Node):
         (the detuning from the qubit transition frequency :math:`\omega_0`).
         Its shape must be ``(3, N)`` where the first dimension :math:`j` indicates the axis and the
         second dimension :math:`k` indicates the collective mode number.
-    sample_times : np.ndarray, optional
+    sample_times : list or tuple or np.ndarray, optional
         A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
         this function calculates the relative phases.
         If you omit it, this function calculates the phases only at the final time of the drives.
@@ -158,7 +159,9 @@ class MsPhases(Node):
         forge.arg("drives", type=List[Pwc]),
         forge.arg("lamb_dicke_parameters", type=np.ndarray),
         forge.arg("relative_detunings", type=np.ndarray),
-        forge.arg("sample_times", type=Optional[np.ndarray], default=None),
+        forge.arg(
+            "sample_times", type=Optional[Union[list, tuple, np.ndarray]], default=None
+        ),
     ]
     rtype = Tensor
     categories = [Category.MOLMER_SORENSEN]
@@ -193,6 +196,7 @@ class MsPhases(Node):
             rd_name="relative_detunings",
         )
         if sample_times is not None:
+            sample_times = np.asarray(sample_times)
             check_sample_times_with_bounds(
                 sample_times, "sample_times", drives[0], "drives[0]"
             )
@@ -236,7 +240,7 @@ class MsPhasesMultitone(Node):
         dimension :math:`\xi` indicates the tone of the global beam,
         the second dimension :math:`j` indicates the axis and the third
         dimension :math:`k` indicates the collective mode number.
-    sample_times : np.ndarray, optional
+    sample_times : list or tuple or np.ndarray, optional
         A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
         this function calculates the relative phases.
         If you omit it, this function calculates the phases only at the final time of the drives.
@@ -306,7 +310,9 @@ class MsPhasesMultitone(Node):
         forge.arg("drives", type=List[Pwc]),
         forge.arg("lamb_dicke_parameters", type=np.ndarray),
         forge.arg("relative_detunings", type=np.ndarray),
-        forge.arg("sample_times", type=Optional[np.ndarray], default=None),
+        forge.arg(
+            "sample_times", type=Optional[Union[list, tuple, np.ndarray]], default=None
+        ),
     ]
     rtype = Tensor
     categories = [Category.MOLMER_SORENSEN]
@@ -363,6 +369,7 @@ class MsPhasesMultitone(Node):
 
         shape = (ion_count, ion_count)
         if sample_times is not None:
+            sample_times = np.asarray(sample_times)
             check_sample_times_with_bounds(
                 sample_times, "sample_times", drives[0], "drives[0]"
             )
@@ -399,7 +406,7 @@ class MsDisplacements(Node):
         (the detuning from the qubit transition frequency :math:`\omega_0`).
         Its shape must be ``(3, N)`` where the first dimension :math:`j` indicates the axis and the
         second dimension :math:`k` indicates the collective mode number.
-    sample_times : np.ndarray, optional
+    sample_times : list or tuple or np.ndarray, optional
         A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
         this function calculates the displacements.
         If you omit it, this function calculates the phases only at the final time of the drives.
@@ -493,7 +500,9 @@ class MsDisplacements(Node):
         forge.arg("drives", type=List[Pwc]),
         forge.arg("lamb_dicke_parameters", type=np.ndarray),
         forge.arg("relative_detunings", type=np.ndarray),
-        forge.arg("sample_times", type=Optional[np.ndarray], default=None),
+        forge.arg(
+            "sample_times", type=Optional[Union[list, tuple, np.ndarray]], default=None
+        ),
     ]
     rtype = Tensor
     categories = [Category.MOLMER_SORENSEN]
@@ -528,6 +537,7 @@ class MsDisplacements(Node):
             rd_name="relative_detunings",
         )
         if sample_times is not None:
+            sample_times = np.asarray(sample_times)
             check_sample_times_with_bounds(
                 sample_times, "sample_times", drives[0], "drives[0]"
             )
