@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -209,7 +209,7 @@ class AnchoredDifferenceBoundedVariables(Node):
     See the "Band-limited pulses with bounded slew rates" example in the
     `How to add smoothing and band-limits to optimized controls
     <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-add-smoothing-and-band-limits-to-
-    optimized-controls#worked-example-band-limited-pulses-with-bounded-slew-rates>`_ user guide.
+    optimized-controls#example-band-limited-pulses-with-bounded-slew-rates>`_ user guide.
     """
 
     name = "anchored_difference_bounded_variables"
@@ -447,7 +447,7 @@ class RealFourierPwcSignal(Node):
     See the "CRAB optimization on a qutrit" example in the
     `How to perform model-based optimization using a Fourier basis
     <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-optimize-controls-using-
-    a-fourier-basis#worked-example-crab-optimization-on-a-qutrit>`_ user guide.
+    a-fourier-basis#example-crab-optimization-on-a-qutrit>`_ user guide.
     """
 
     name = "real_fourier_pwc_signal"
