@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -36,10 +36,10 @@ from qctrlcommons.node.utils import (
     validate_shape,
 )
 from qctrlcommons.preconditions import (
-    NumpyDtype,
     check_argument,
     check_argument_integer,
     check_argument_iterable,
+    check_argument_real_vector,
     check_duration,
     check_numeric_numpy_array,
     check_operator,
@@ -136,12 +136,7 @@ class PwcOperation(Node):
         durations = kwargs.get("durations")
         values = kwargs.get("values")
         time_dimension = kwargs.get("time_dimension")
-        check_argument(
-            durations.size != 0,
-            "The `durations` must be a non-empty array.",
-            {"durations": durations},
-        )
-        check_numeric_numpy_array(durations, "durations", dtype=NumpyDtype.REAL)
+        check_argument_real_vector(durations, "durations")
         check_numeric_numpy_array(values, "values")
         check_argument_integer(time_dimension, "time_dimension")
         value_shape = validate_shape(values, "values")
@@ -151,11 +146,6 @@ class PwcOperation(Node):
             {"values": values},
         )
         durations_shape = validate_shape(durations, "durations")
-        check_argument(
-            len(durations_shape) == 1,
-            "The shape of durations must have exactly one dimension.",
-            {"durations": durations},
-        )
         check_argument(
             -len(value_shape) <= time_dimension < len(value_shape),
             "The `time_dimension` must be a valid `values` dimension.",
@@ -1009,7 +999,7 @@ class TimeEvolutionOperatorsPwc(Node):
     ----------
     hamiltonian : Pwc
         The control Hamiltonian, or batch of control Hamiltonians.
-    sample_times : np.ndarray(1D, real)
+    sample_times : list or tuple or np.ndarray(1D, real)
         The N times at which you want to sample the unitaries. Must be ordered and contain
         at least one element.
     name : str, optional
@@ -1043,7 +1033,7 @@ class TimeEvolutionOperatorsPwc(Node):
     >>> duration = np.pi
     >>> hamiltonian = graph.constant_pwc_operator(duration=duration, operator=sigma_x / 2)
     >>> graph.time_evolution_operators_pwc(
-    ...     hamiltonian=hamiltonian, sample_times=np.array([duration]), name="unitaries"
+    ...     hamiltonian=hamiltonian, sample_times=[duration], name="unitaries"
     ... )
     <Tensor: name="unitaries", operation_name="time_evolution_operators_pwc", shape=(1, 2, 2)>
     >>> result = qctrl.functions.calculate_graph(graph=graph, output_node_names=["unitaries"])
@@ -1058,7 +1048,7 @@ class TimeEvolutionOperatorsPwc(Node):
     name = "time_evolution_operators_pwc"
     args = [
         forge.arg("hamiltonian", type=Pwc),
-        forge.arg("sample_times", type=np.ndarray),
+        forge.arg("sample_times", type=Union[list, tuple, np.ndarray]),
     ]
     rtype = Tensor
     categories = [Category.TIME_EVOLUTION]
@@ -1075,6 +1065,7 @@ class TimeEvolutionOperatorsPwc(Node):
         batch_shape, value_shape = validate_batch_and_value_shapes(
             hamiltonian, "hamiltonian"
         )
+        sample_times = np.asarray(sample_times)
         check_sample_times_with_bounds(
             sample_times, "sample_times", hamiltonian, "hamiltonian"
         )
@@ -1092,7 +1083,7 @@ class SamplePwc(Node):
     ----------
     pwc : Pwc
         The Pwc to sample.
-    sample_times : np.ndarray(1D, real)
+    sample_times : list or tuple or np.ndarray(1D, real)
         The times at which you want to sample the Pwc. Must be ordered, contain
         at least one element, and lie between 0 and the duration of the Pwc.
         For a sample time :math:`t` the returned value
@@ -1118,7 +1109,10 @@ class SamplePwc(Node):
     """
 
     name = "sample_pwc"
-    args = [forge.arg("pwc", type=Pwc), forge.arg("sample_times", type=np.ndarray)]
+    args = [
+        forge.arg("pwc", type=Pwc),
+        forge.arg("sample_times", type=Union[list, tuple, np.ndarray]),
+    ]
     rtype = Tensor
     categories = [Category.BUILDING_PIECEWISE_CONSTANT_HAMILTONIANS]
 
@@ -1128,6 +1122,7 @@ class SamplePwc(Node):
         check_argument(isinstance(pwc, Pwc), "The pwc must be a Pwc.", {"pwc": pwc})
         batch_shape, value_shape = validate_batch_and_value_shapes(pwc, "pwc")
         sample_times = kwargs.get("sample_times")
+        sample_times = np.asarray(sample_times)
         check_sample_times_with_bounds(sample_times, "sample_times", pwc, "pwc")
         check_argument(
             sample_times[0] >= 0,
