@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -343,7 +343,7 @@ class StateEvolutionPwc(Node):
         relatively sparse (contain mostly zeros).
     krylov_subspace_dimension : Tensor or int
         The dimension of the Krylov subspace `k` for the Lanczos method.
-    sample_times : np.ndarray(1D, real), optional
+    sample_times : list or tuple or np.ndarray(1D, real), optional
         The N times at which you want to sample the state. Elements must be non-negative
         and strictly increasing, with a supremum that is the duration of the `hamiltonian`.
         If omitted only the evolved state at the final time of the control Hamiltonian
@@ -415,7 +415,9 @@ class StateEvolutionPwc(Node):
         forge.arg("initial_state", type=TensorLike),
         forge.arg("hamiltonian", type=Union[Pwc, SparsePwc]),
         forge.arg("krylov_subspace_dimension", type=Union[int, Tensor]),
-        forge.arg("sample_times", type=Optional[np.ndarray], default=None),
+        forge.arg(
+            "sample_times", type=Optional[Union[list, tuple, np.ndarray]], default=None
+        ),
     ]
     rtype = Tensor
     categories = [Category.LARGE_SYSTEMS, Category.TIME_EVOLUTION]
@@ -434,6 +436,7 @@ class StateEvolutionPwc(Node):
         sample_times = kwargs.get("sample_times")
         check_numeric_numpy_array(initial_state, "initial_state")
         if sample_times is not None:
+            sample_times = np.asarray(sample_times)
             check_sample_times_with_bounds(
                 sample_times, "sample_times", hamiltonian, "hamiltonian"
             )
