@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -403,11 +403,11 @@ class TimeEvolutionOperatorsStf(Node):
     ----------
     hamiltonian : Stf
         The control Hamiltonian, or batch of control Hamiltonians.
-    sample_times : np.ndarray(1D, real)
+    sample_times : list or tuple or np.ndarray(1D, real)
         The N times at which you want to sample the unitaries. Must be ordered and contain
         at least one element. If you don't provide `evolution_times`, `sample_times` must
         start with 0.
-    evolution_times : np.ndarray(1D, real), optional
+    evolution_times : list or tuple or np.ndarray(1D, real), optional
         The times at which the Hamiltonian should be sampled for the Runge–Kutta integration.
         If you provide it, must start with 0 and be ordered.
         If you don't provide it, the `sample_times` are used for the integration.
@@ -444,7 +444,7 @@ class TimeEvolutionOperatorsStf(Node):
     >>> hamiltonian = gaussian_drive * sigma_x * np.sqrt(np.pi) / 2
     >>> graph.time_evolution_operators_stf(
     ...     hamiltonian=hamiltonian,
-    ...     sample_times=np.array([duration]),
+    ...     sample_times=[duration],
     ...     evolution_times=np.linspace(0, duration, 200),
     ...     name="unitaries",
     ... )
@@ -457,8 +457,12 @@ class TimeEvolutionOperatorsStf(Node):
     name = "time_evolution_operators_stf"
     args = [
         forge.arg("hamiltonian", type=Stf),
-        forge.arg("sample_times", type=np.ndarray),
-        forge.arg("evolution_times", type=Optional[np.ndarray], default=None),
+        forge.arg("sample_times", type=Union[list, tuple, np.ndarray]),
+        forge.arg(
+            "evolution_times",
+            type=Optional[Union[list, tuple, np.ndarray]],
+            default=None,
+        ),
     ]
     rtype = Tensor
     categories = [Category.TIME_EVOLUTION]
@@ -467,6 +471,7 @@ class TimeEvolutionOperatorsStf(Node):
     def create_node_data(cls, _operation, **kwargs):
         hamiltonian = kwargs.get("hamiltonian")
         sample_times = kwargs.get("sample_times")
+        sample_times = np.asarray(sample_times)
         evolution_times = kwargs.get("evolution_times")
         check_argument(
             isinstance(hamiltonian, Stf),
@@ -480,6 +485,7 @@ class TimeEvolutionOperatorsStf(Node):
         validate_hamiltonian(hamiltonian, "hamiltonian")
         time_count = len(sample_times)
         if evolution_times is not None:
+            evolution_times = np.asarray(evolution_times)
             check_sample_times(evolution_times, "evolution_times")
             check_argument(
                 evolution_times[0] == 0,
@@ -578,14 +584,14 @@ class SincConvolutionKernel(Node):
     r"""
     Create a convolution kernel representing the sinc function.
 
-    Use this kernel to eliminate frequencies above a certain cutoff.
+    Use this kernel to eliminate angular frequencies above a certain cutoff.
 
     Parameters
     ----------
     cutoff_frequency : float or Tensor
-        Upper limit :math:`\omega_c` of the range of frequencies that you want
+        Upper limit :math:`\omega_c` of the range of angular frequencies that you want
         to preserve. The filter eliminates components of the signal that have
-        higher frequencies.
+        higher angular frequencies.
 
     Returns
     -------
@@ -601,16 +607,14 @@ class SincConvolutionKernel(Node):
 
     Notes
     -----
-    The range of frequencies that this kernel lets pass is
-    :math:`[-\omega_c, \omega_c]`. After a Fourier transform to convert from
-    frequency domain to time domain, this becomes:
+    The sinc kernel that this node represents is defined as
 
     .. math::
-        \frac{1}{2\pi} \int_{-\omega_c}^{\omega_c} \mathrm{d}\omega
-        e^{i \omega t} = \frac{\sin(\omega_c t)}{\pi t}.
+        K(t) = \frac{\sin(\omega_c t)}{\pi t}.
 
-    The function on the right side of the equation is the sinc function.
-    Its integral is the sine integral function (Si).
+    In the frequency domain, the sinc function is constant in the range
+    :math:`[-\omega_c, \omega_c]` and zero elsewhere. The filter it represents therefore
+    passes angular frequencies only in that range.
 
     For more information on `Stf` nodes see the `Working with time-dependent functions in
     Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
@@ -649,7 +653,7 @@ class GaussianConvolutionKernel(Node):
     r"""
     Create a convolution kernel representing a normalized Gaussian.
 
-    Use this kernel to allow frequencies in the range roughly determined by
+    Use this kernel to allow angular frequencies in the range roughly determined by
     its width, and progressively suppress components outside that range.
 
     Parameters
@@ -657,7 +661,7 @@ class GaussianConvolutionKernel(Node):
     std : float or Tensor
         Standard deviation :math:`\sigma` of the Gaussian in the time domain.
         The standard deviation in the frequency domain is its inverse, so that
-        a high value of this parameter lets fewer frequencies pass.
+        a high value of this parameter lets fewer angular frequencies pass.
     offset : float or Tensor, optional
         Center :math:`\mu` of the Gaussian distribution in the time domain.
         Use this to offset the signal in time. Defaults to 0.
@@ -674,14 +678,14 @@ class GaussianConvolutionKernel(Node):
 
     Notes
     -----
-    The Gaussian that this node represents is normalized in the time domain:
+    The Gaussian kernel that this node represents is defined as:
 
     .. math::
-        \frac{e^{-(t-\mu)^2/(2\sigma^2)}}{\sqrt{2\pi\sigma^2}}.
+        K(t) = \frac{e^{-(t-\mu)^2/(2\sigma^2)}}{\sqrt{2\pi\sigma^2}}.
 
     In the frequency domain, this Gaussian has standard deviation
     :math:`\omega_c= \sigma^{-1}`. The filter it represents therefore
-    passes frequencies roughly in the range :math:`[-\omega_c, \omega_c]`.
+    passes angular frequencies roughly in the range :math:`[-\omega_c, \omega_c]`.
 
     For more information on `Stf` nodes see the `Working with time-dependent functions in
     Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
@@ -727,7 +731,7 @@ class SampleStf(Node):
     ----------
     stf : Stf
         The Stf to sample.
-    sample_times : np.ndarray(1D, real)
+    sample_times : list or tuple or np.ndarray(1D, real)
         The times at which you want to sample the Stf. Must be ordered and contain
         at least one element.
     name : str, optional
@@ -753,7 +757,10 @@ class SampleStf(Node):
     """
 
     name = "sample_stf"
-    args = [forge.arg("stf", type=Stf), forge.arg("sample_times", type=np.ndarray)]
+    args = [
+        forge.arg("stf", type=Stf),
+        forge.arg("sample_times", type=Union[list, tuple, np.ndarray]),
+    ]
     rtype = Tensor
     categories = [Category.BUILDING_SMOOTH_HAMILTONIANS]
 
@@ -763,6 +770,7 @@ class SampleStf(Node):
         check_argument(isinstance(stf, Stf), "The stf must be an Stf.", {"stf": stf})
         batch_shape, value_shape = validate_batch_and_value_shapes(stf, "stf")
         sample_times = kwargs.get("sample_times")
+        sample_times = np.asarray(sample_times)
         check_sample_times(sample_times, "sample_times")
         time_count = len(sample_times)
         shape = batch_shape + (time_count,) + value_shape
