@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -32,6 +32,7 @@ from qctrlcommons.preconditions import (
     check_argument_iterable,
     check_argument_operator,
     check_argument_orthogonal_projection_operator,
+    check_argument_real_vector,
     check_numeric_numpy_array,
 )
 
@@ -835,12 +836,8 @@ def validate_filter_function_input(
         {"control_hamiltonian": control_hamiltonian, "noise_operator": noise_operator},
     )
     dimension = value_shape[-1]
-    check_numeric_numpy_array(frequencies, "frequencies")
-    check_argument(
-        len(validate_shape(frequencies, "frequencies")) == 1,
-        "The frequencies must be a 1D array.",
-        {"frequencies": frequencies},
-    )
+
+    check_argument_real_vector(frequencies, "frequencies")
     if sample_count is not None:
         check_argument_integer(sample_count, "sample_count")
         check_argument(
