@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -278,7 +278,7 @@ def check_argument_real_vector(argument, argument_name):
     """
     Raises QctrlArgumentsValueError if the argument is not a 1-D array of real numbers.
     """
-    check_numeric_numpy_array(argument, argument_name)
+    check_numeric_numpy_array(argument, argument_name, dtype=NumpyDtype.REAL)
 
     # This makes sure that extracting shape doesn't throw an error if the
     # user passes a list. Instead, a list will fail the next test, with a
@@ -295,11 +295,6 @@ def check_argument_real_vector(argument, argument_name):
         f"{argument_name} must be an array with at least one element.",
         {argument_name: argument},
     )
-    check_argument(
-        np.all(np.isreal(argument)),
-        f"{argument_name} must be real numbers.",
-        {argument_name: argument},
-    )
 
 
 class NumpyDtype(Enum):
@@ -393,7 +388,7 @@ def check_sample_times(sample_times, sample_times_name):
     """
     check_argument_real_vector(sample_times, sample_times_name)
     check_argument(
-        # note that this is also true for sample_time only holding one element or empty.
+        # Note that this is also true for sample_times only holding one element or empty.
         np.all(np.diff(sample_times) > 0),
         f"{sample_times_name} must be ordered and not have duplicate values.",
         {sample_times_name: sample_times},
